@@ -2,10 +2,10 @@ from __future__ import annotations
 
 from copy import deepcopy
 from dataclasses import dataclass
-from typing import Any, Dict, Optional, Tuple
+from typing import Any
 
 from matplotlib import colors
-from matplotlib.figure import Axes
+from matplotlib.axes import Axes
 from matplotlib.patches import PathPatch
 from matplotlib.path import Path
 
@@ -23,14 +23,19 @@ class Link:
     normal_color: str = "grey"
     inverted_color: str = "red"
     alpha: float = 0.8
-    v: Optional[float] = None
+    v: float | None = None
     vmin: float = 0
     vmax: float = 100
     curve: bool = False
     size_ratio: float = 1.0
-    patch_kws: Optional[Dict[str, Any]] = None
+    patch_kws: dict[str, Any] | None = None
 
     def __post_init__(self):
+        # start-end value for HTML display
+        self._display_track_start1 = self.track_start1
+        self._display_track_end1 = self.track_end1
+        self._display_track_start2 = self.track_start2
+        self._display_track_end2 = self.track_end2
         # Check color string
         if not colors.is_color_like(self.normal_color):
             err_msg = f"'normal_color={self.normal_color}' is not color like."
@@ -61,14 +66,29 @@ class Link:
         """Track length2"""
         return abs(self.track_end2 - self.track_start2)
 
-    def plot_link(self, ax: Axes, ylim: Tuple[float, float] = (-1.0, 1.0)) -> None:
+    @property
+    def gid(self) -> str:
+        """Group ID"""
+        trans_dict = {e: "_" for e in list(" /:;()+.,'`\"\\!|^~[]{}<>#$%&@?=")}
+        trans_table = str.maketrans(trans_dict)
+        name1 = self.track_name1.translate(trans_table)
+        start1 = self._display_track_start1
+        end1 = self._display_track_end1
+        name2 = self.track_name2.translate(trans_table)
+        start2 = self._display_track_start2
+        end2 = self._display_track_end2
+        track_info = f"{name1}_{start1}_{end1}_{name2}_{start2}_{end2}"
+        identity = "na" if self.v is None else int(self.v)
+        return f"Link_{track_info}_{identity}"
+
+    def plot_link(self, ax: Axes, ylim: tuple[float, float] = (-1.0, 1.0)) -> None:
         """Plot link
 
         Parameters
         ----------
         ax : Axes
             Matplotlib axes object to be plotted
-        ylim: Tuple[flaot, float], optional
+        ylim: tuple[flaot, float], optional
             Min-Max y coordinatess
         """
         ymin, ymax = ylim[0] * self.size_ratio, ylim[1] * self.size_ratio
@@ -98,12 +118,12 @@ class Link:
         codes, verts = zip(*path_data)
         ax.add_patch(PathPatch(Path(verts, codes), **self._patch_kwargs()))
 
-    def _patch_kwargs(self) -> Dict[str, Any]:
+    def _patch_kwargs(self) -> dict[str, Any]:
         """Patch keyword arguments dict
 
         Returns
         -------
-        patch_kwargs : Dict[str, Any]
+        patch_kwargs : dict[str, Any]
             Patch keyword arguments dict
         """
         patch_kws = {} if self.patch_kws is None else self.patch_kws
@@ -112,6 +132,7 @@ class Link:
             "fc": self.color,
             "ec": "grey",
             "lw": lw,
+            "gid": self.gid,
             **patch_kws,
         }
 
@@ -148,12 +169,12 @@ class Link:
         track_link_length2 = self.track_end2 - self.track_start2
         return track_link_length1 * track_link_length2 < 0
 
-    def add_offset(self, track_name2offset: Dict[str, int]) -> Link:
+    def add_offset(self, track_name2offset: dict[str, int]) -> Link:
         """Add offset to each link position
 
         Parameters
         ----------
-        track_name2offset : Dict[str, int]
+        track_name2offset : dict[str, int]
             Track name & offset dict
 
         Returns
